@@ -15,7 +15,7 @@ CPU::Z80::Assembler::Program - Represents one assembly program
 use strict;
 use warnings;
 
-our $VERSION = '2.19';
+our $VERSION = '2.20';
 
 use CPU::Z80::Assembler::Parser;
 use CPU::Z80::Assembler::Segment;
@@ -311,6 +311,10 @@ sub _locate_opcodes {
 								$address, $segment->address));
 				die; # NOT REACHED
 			}
+			# check for new address
+			elsif ($segment->address > $address) {
+				$address = $segment->address;
+			}
 		}
 		else {
 			$segment->address( $address ) if $final;
